@@ -30,7 +30,10 @@ class TablasVC(SQLConnector):
         self._idsApiCammesa = {}
         self._ucs = []
         self._nemos = []
-        self.__parques = parques
+        if isinstance(parques,str):
+            self.__parques = [parques,]
+        else:
+            self.__parques = parques
         self.__clientes = clientes
         self.solo_CROM = solo_CROM
         
